@@ -113,7 +113,7 @@ spark_worker_execute_closure <- function(
 
 spark_worker_clean_factors <- function(result) {
   if (any(sapply(result, is.factor))) {
-    result <- as.data.frame(lapply(result, function(x) if (is.factor(x)) as.character(x) else x), stringsAsFactors = F)
+    result <- as.data.frame(lapply(result, function(x) if (is.factor(x)) as.character(x) else x), stringsAsFactors = FALSE)
   }
 
   result
@@ -258,7 +258,7 @@ spark_worker_apply_arrow <- function(sc, config) {
     result <- NULL
 
     if (!is.null(df)) {
-      colnames(df) <- columnNames[1:length(colnames(df))]
+      colnames(df) <- columnNames[seq_along(colnames(df))]
 
       result <- spark_worker_execute_closure(
         closure,
@@ -366,8 +366,7 @@ spark_worker_apply <- function(sc, config) {
         tibble::tibble(encoded = lapply(data, function(x) x[[1]]))
       } else {
         do.call(rbind.data.frame, c(data, list(stringsAsFactors = FALSE)))
-      }
-    )
+      })
 
     if (!config$single_binary_column) {
       # rbind removes Date classes so we re-assign them here
@@ -385,7 +384,7 @@ spark_worker_apply <- function(sc, config) {
         }
 
         # cast column to correct type, for instance, when dealing with NAs.
-        for (i in 1:ncol(df)) {
+        for (i in seq_along(df)) {
           target_type <- funcContext$column_types[[i]]
           if (!is.null(target_type) && class(df[[i]]) != target_type) {
             df[[i]] <- do.call(paste("as", target_type, sep = "."), args = list(df[[i]]))
@@ -394,7 +393,7 @@ spark_worker_apply <- function(sc, config) {
       }
     }
 
-    colnames(df) <- columnNames[1:length(colnames(df))]
+    colnames(df) <- columnNames[seq_along(colnames(df))]
 
     result <- spark_worker_execute_closure(
       closure,
@@ -420,7 +419,7 @@ spark_worker_apply <- function(sc, config) {
   if (!is.null(all_results) && nrow(all_results) > 0) {
     worker_log("updating ", nrow(all_results), " rows")
 
-    all_data <- lapply(1:nrow(all_results), function(i) as.list(all_results[i, ]))
+    all_data <- lapply(seq_len(nrow(all_results)), function(i) as.list(all_results[i, ]))
 
     worker_invoke(context, "setResultArraySeq", all_data)
     worker_log("updated ", nrow(all_results), " rows")
